@@ -15,9 +15,10 @@ maxWithoutNA <- function(x) ifelse( !all(is.na(x)), max(x, na.rm=TRUE), NA)
 #' @section Methods:
 #' \describe{
 #'   \item{\code{initialize()}}{initializes the object}
-#'   \item{\code{addFilename(source, filename)}}{add filename to the ledger}
-#'   \item{\code{getIdFilename(source, filename)}}{Returns id/row of source and filenames parameters in the ledger}
-#'   \item{\code{updateStatus(source, filename, status, status.field = 'status', scraped.polyhedron = NA, obs ='')}}{Updates status of source and filenames parameters in Ledger }
+#'   \item{\code{addFilename(source, source.filename)}}{add filename to the ledger}
+#'   \item{\code{getIdFilename(source, source.filename)}}{Returns id/row of source and filenames parameters in the ledger}
+#'   \item{\code{getCRCFilename(source, source.filename)}}{Returns CRC of the source filename for storing in db folder}
+#'   \item{\code{updateStatus(source, source.filename, status, status.field = 'status', scraped.polyhedron = NA, obs ='')}}{Updates status of source and filenames parameters in Ledger }
 #'   \item{\code{savePreloadedData()}}{Internal method which saves a file with an estimation of time required time to scrape each filename}
 #'   \item{\code{loadPreloadedData()}}{Load a file with an estimation of time required time to scrape each filename}
 #'   \item{\code{getSizeToTimeScrape(sources, time2scrape = 60)}}{Estimates how much filenames could be scraped in a time frame, considering data retrieved with loadPreloadedData}
@@ -30,7 +31,7 @@ maxWithoutNA <- function(x) ifelse( !all(is.na(x)), max(x, na.rm=TRUE), NA)
 #' @format \code{\link{R6Class}} object.
 #' @docType class
 #' @import futile.logger
-#' @import utils
+#' @import utils digest
 #' @importFrom R6 R6Class
 #' @export
 ScraperLedger.class <- R6::R6Class("ScraperLedger",
@@ -43,8 +44,8 @@ ScraperLedger.class <- R6::R6Class("ScraperLedger",
    initialize = function() {
      self$df <- data.frame(id           = character(),
                            source       = character(),
-                           number       = numeric(),
-                           filename     = character(),
+                           file.id       = numeric(),
+                           source.filename     = character(),
                            start.scrape = as.POSIXct(character()),
                            end.scrape   = as.POSIXct(character()),
                            status       = character(),
@@ -64,21 +65,24 @@ ScraperLedger.class <- R6::R6Class("ScraperLedger",
      self$loadPreloadedData()
      self
    },
-   addFilename = function(source, filename){
+   getAvailableSources = function(){
+    sort(unique(self$df$source))
+   },
+   addFilename = function(source, source.filename){
      r <- NULL
      default.status <- "queued"
-     if (is.null(self$getIdFilename(source, filename))){
-       futile.logger::flog.info(paste("Adding Filename to ledger ",source, filename))
+     if (is.null(self$getIdFilename(source, source.filename))){
+       futile.logger::flog.info(paste("Adding Filename to ledger ",source, source.filename))
        r <- nrow(self$df)+1
        status.field <- "status"
        self$countStatusUse(status.field = status.field, status = default.status)
        states.row <- which(self$states$status.field %in% status.field &
                              self$states$status %in% default.status)
-       number <- self$states[states.row,"count"]
+       file.id <- self$states[states.row,"count"]
 
        #obtain preloaded.time2scrape
        row.preloaded.t2s <- which(self$preloaded.data$source == source &
-                                    self$preloaded.data$filename==filename)
+                                    self$preloaded.data$filename==source.filename)
        if (length(row.preloaded.t2s)==1){
          preloaded.data <- self$preloaded.data[row.preloaded.t2s,]
          self$df[r,c("preloaded.name")]<-
@@ -89,14 +93,13 @@ ScraperLedger.class <- R6::R6Class("ScraperLedger",
        else{
          preloaded.time2scrape <- NA
        }
-       self$df[r,c("id","source","filename","status")]<- c(r,source,filename,default.status)
-       self$df[r,c("number")]<- c(number)
+       self$df[r,c("id","source","source.filename","status")]<- c(r, source, source.filename, default.status)
        self$dirty <- TRUE
      }
      r
    },
-   getIdFilename = function(source, filename){
-     r <- which(self$df$source == source & self$df$filename == filename)
+   getIdFilename = function(source, source.filename){
+     r <- which(self$df$source == source & self$df$source.filename == source.filename)
      if (length(r)>0){
        self$df[r,"id"]
      }
@@ -105,7 +108,10 @@ ScraperLedger.class <- R6::R6Class("ScraperLedger",
      }
      r
    },
-   updateStatus = function(source, filename, status, status.field = "status",
+   getCRCPolyhedronName = function(source, polyhedron.name){
+     digest(polyhedron.name,algo="crc32")
+   },
+   updateStatus = function(source, source.filename, status, status.field = "status",
                            scraped.polyhedron = NA, obs =""){
      if (is.null(obs)){
        obs <- ""
@@ -113,9 +119,9 @@ ScraperLedger.class <- R6::R6Class("ScraperLedger",
      if (!status.field %in% c("status","status.test"))
        stop(paste("Cannot update invalid status field",status.field))
      ret <- NULL
-     retrieved.id <- self$getIdFilename(source = source, filename = filename)
+     retrieved.id <- self$getIdFilename(source = source, source.filename = source.filename)
      if (length(retrieved.id)!=1){
-       stop(paste("There must be a unique row for",source,filename,"and have",length(retrieved.id)))
+       stop(paste("There must be a unique row for",source,source.filename,"and have",length(retrieved.id)))
      }
      if (status.field == "status"){
        end.scrape <- Sys.time()
@@ -167,11 +173,10 @@ ScraperLedger.class <- R6::R6Class("ScraperLedger",
    updateCalculatedFields = function(){
      resolveScrapedPreloaded <- function(x, field){maxWithoutNA(c(x[paste("scraped",field,sep=".")],
                                                                   x[paste("preloaded",field,sep=".")]))}
-     if (!"name" %in% names(self$df)){
+     if (!"vertices" %in% names(self$df)){
        self$dirty <- TRUE
      }
      if (self$dirty){
-       self$df$name     <-  apply(self$df,MARGIN = 1, FUN=function(x){resolveScrapedPreloaded(x=x, field="name")} )
        self$df$vertices <-  as.numeric(apply(self$df,MARGIN = 1, FUN=function(x){resolveScrapedPreloaded(x=x, field="vertices")}))
        self$df$faces    <-  as.numeric(apply(self$df,MARGIN = 1, FUN=function(x){resolveScrapedPreloaded(x=x, field="faces")}))
        self$dirty <- FALSE
@@ -179,22 +184,22 @@ ScraperLedger.class <- R6::R6Class("ScraperLedger",
    },
    getAvailablePolyhedra = function(sources = names(getPackageEnvir(".available.sources")),
                                     search.string = "",
-                                    ret.fields = c("source","name","vertices","faces","status"),
+                                    ret.fields = c("source","scraped.name","vertices","faces","status"),
                                     ignore.case = TRUE){
      self$updateCalculatedFields()
      if (is.null(ret.fields)){
        ret.fields <- 1:ncol(self$df)
      }
-     ret <- self$df[!is.na(self$df$name) & self$df$source %in% sources,
+     ret <- self$df[!is.na(self$df$scraped.name) & self$df$source %in% sources,
                     ret.fields]
      if (!is.null(search.string)) {
-       ret <- ret[grepl(search.string, ret$name,ignore.case = ignore.case),]
+       ret <- ret[grepl(search.string, ret$scraped.name,ignore.case = ignore.case),]
      }
      ret <- ret[order(ret$vertices,ret$faces,ret$source),]
      ret
    },
    savePreloadedData = function(){
-     preloaded.data <- self$df[!is.na(self$df$time.scraped),c("source","filename","scraped.name","scraped.vertices","scraped.faces","time.scraped")]
+     preloaded.data <- self$df[!is.na(self$df$time.scraped),c("source","source.filename","scraped.name","scraped.vertices","scraped.faces","time.scraped")]
      preloaded.data <- preloaded.data[order(preloaded.data$time.scraped,
                                                             preloaded.data$source,
                                                             preloaded.data$filename),]
@@ -276,7 +281,7 @@ ScraperLedger.class <- R6::R6Class("ScraperLedger",
        }
        ret <- self$df[filtred.rows,]
        if (order.by.vertices.faces){
-         ret <- ret[order(ret$vertices,ret$faces,ret$source,ret$name),]
+         ret <- ret[order(ret$vertices,ret$faces,ret$source,ret$scraped.name),]
        }
      }
      ret
